GIcons class

Constructors

GIcons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) IconData?

Static Methods

fromString(String key) IconData?
getIconsName() List<String>

Constants

add → const IconData
addBalance → const IconData
addCircle → const IconData
addSquare → const IconData
advertising → const IconData
afternoon → const IconData
alert → const IconData
arHoriz → const IconData
arrowDown → const IconData
arrowLeft → const IconData
arrowRight → const IconData
arrowUp → const IconData
arVert → const IconData
award → const IconData
bet → const IconData
bike → const IconData
bill → const IconData
book → const IconData
bookmark → const IconData
boy → const IconData
briefcase → const IconData
brightness1 → const IconData
brightness2 → const IconData
brightness3 → const IconData
brightness4 → const IconData
brightness5 → const IconData
brightness6 → const IconData
brightness7 → const IconData
brush → const IconData
bulb → const IconData
bulbNumber → const IconData
bulbOn → const IconData
bull → const IconData
cabala → const IconData
camera → const IconData
campaign → const IconData
cancel → const IconData
cashier → const IconData
cellPhone → const IconData
chart → const IconData
chat → const IconData
check → const IconData
checked → const IconData
checkOutline → const IconData
chevronDl → const IconData
chevronDown → const IconData
chevronDr → const IconData
chevronLeft → const IconData
chevronRight → const IconData
chevronTl → const IconData
chevronTr → const IconData
chevronUp → const IconData
chronometer → const IconData
close → const IconData
closeMenu → const IconData
cloud → const IconData
clover → const IconData
cold → const IconData
country → const IconData
cow → const IconData
dashboard → const IconData
deal → const IconData
delete → const IconData
delta → const IconData
deltaCold → const IconData
deltaHot → const IconData
dictation → const IconData
disabled → const IconData
doc → const IconData
download → const IconData
downMenu → const IconData
drink → const IconData
edit → const IconData
error → const IconData
evening → const IconData
event → const IconData
eventAvailable → const IconData
exitToApp → const IconData
facebook → const IconData
faceId → const IconData
favorite → const IconData
favoriteBorder → const IconData
favoriteDislike → const IconData
filter → const IconData
flag → const IconData
flashCards → const IconData
folder → const IconData
folderAdd → const IconData
folderDelete → const IconData
folderOpen → const IconData
folderSecure → const IconData
folderSpecial → const IconData
fullDot → const IconData
fullSquare → const IconData
game → const IconData
gift → const IconData
girl → const IconData
github → const IconData
gitlab → const IconData
happyFace → const IconData
hearing → const IconData
help → const IconData
home → const IconData
hot → const IconData
hotCold → const IconData
hourglass → const IconData
images → const IconData
info → const IconData
instagram → const IconData
jpg → const IconData
lang → const IconData
langHelp → const IconData
language → const IconData
launch → const IconData
linkedin → const IconData
list → const IconData
loadAudio → const IconData
lock → const IconData
lockOpen → const IconData
lotto → const IconData
mail → const IconData
map → const IconData
match → const IconData
mic → const IconData
micOff → const IconData
month → const IconData
moreHoriz → const IconData
moreLess → const IconData
moreVert → const IconData
next → const IconData
noAdvertising → const IconData
noAudio → const IconData
noEvent → const IconData
noImage → const IconData
none → const IconData
noShow → const IconData
notification → const IconData
notifications → const IconData
notificationsActive → const IconData
notificationsOff → const IconData
npm → const IconData
number → const IconData
oddEven → const IconData
openBox → const IconData
openMenu → const IconData
oral → const IconData
page → const IconData
parking → const IconData
past → const IconData
pause → const IconData
payment → const IconData
pdf → const IconData
pencil → const IconData
people → const IconData
person → const IconData
personStatus → const IconData
phone → const IconData
photoId → const IconData
place → const IconData
playArrow → const IconData
png → const IconData
politician → const IconData
previous → const IconData
pushPin → const IconData
questionAnswer → const IconData
rate → const IconData
rbChecked → const IconData
rbUnchecked → const IconData
rearrange → const IconData
record → const IconData
recording → const IconData
refresh → const IconData
refreshAudio → const IconData
remove → const IconData
removeCircle → const IconData
removeSquare → const IconData
restore → const IconData
retryScan → const IconData
sadFace → const IconData
save → const IconData
scan → const IconData
searchNumber → const IconData
searchPage → const IconData
searchPerson → const IconData
send → const IconData
settings → const IconData
share → const IconData
shoppingCart → const IconData
shuffle → const IconData
sidebarClose → const IconData
sidebarOpen → const IconData
skipNext → const IconData
skipPrevious → const IconData
slider → const IconData
star → const IconData
starBorder → const IconData
starHalf → const IconData
stop → const IconData
store → const IconData
sum → const IconData
sumCold → const IconData
sumHot → const IconData
television → const IconData
temperature → const IconData
test → const IconData
testDaily → const IconData
testRepeat → const IconData
testStar → const IconData
thumbDown → const IconData
thumbUp → const IconData
ticket → const IconData
time → const IconData
timeRecord → const IconData
total → const IconData
trophy → const IconData
twitter → const IconData
unchecked → const IconData
undo → const IconData
unpin → const IconData
upBalls → const IconData
upcoming → const IconData
update → const IconData
upload → const IconData
upMenu → const IconData
url → const IconData
verified → const IconData
verifiedUser → const IconData
video → const IconData
visibility → const IconData
visibilityOff → const IconData
volume → const IconData
volumeLow → const IconData
volumeMedium → const IconData
volumeOff → const IconData
volumeUp → const IconData
vrMobile → const IconData
walk → const IconData
wifi → const IconData
youtube → const IconData